@@ -2,30 +2,28 @@
 """
 
 
-from typing import List
-from typing import Optional
-
-from apyscript.display.display_object import DisplayObject
+from apyscript.type import Array
 from apyscript.type import Int
 from apyscript.type import Number
+from apyscript.type import String
 
 
 class GraphicsClearInterface:
 
-    _fill_color: Optional[str] = None
+    _fill_color: String
     _fill_alpha: Number
-    _line_color: Optional[str] = None
-    _line_thickness: Int = Int(1)
+    _line_color: String
+    _line_thickness: Int
     _line_alpha: Number
-    _childs: List[DisplayObject]
+    _childs: Array
 
     def clear(self) -> None:
         """
         Clear all graphics and reset fill and line settings.
         """
-        self._fill_color = None
+        self._fill_color.value = ''
         self._fill_alpha = Number(1.0)
-        self._line_color = None
+        self._line_color.value = ''
         self._line_thickness = Int(1)
         self._line_alpha = Number(1.0)
         while self._childs:
